@@ -316,19 +316,24 @@ namespace Tomboy
 			string [] authors = new string [] {
 				Catalog.GetString ("Primary Development:"),
 				"\tAlex Graveley (original author)",
+				"\tAaron Borden (maintainer)",
+				"\t\t<adborden@live.com>",
+				"\tBenjamin Podszun (maintainer)",
+				"\t\t<benjamin.podszun@gmail.com>",
+				"\tGreg Poirier (maintainer)",
+				"\t\t<grep@binary-snobbery.com>",
+				"\tJared Jennings (maintainer)",
+				"\t\t<jaredljennings@gmail.com>",
+				"\tSandy Armstrong (retired maintainer)",
 				"\tBoyd Timothy (retired maintainer)",
-				"\tSandy Armstrong (maintainer)",
-				"\t\t<sanfordarmstrong@gmail.com>",
 				"",
 				Catalog.GetString ("Contributors:"),
 				"\tAaron Bockover",
-				"\tAaron Bordern",
 				"\tAlejandro Cura",
 				"\tAlexey Nedilko",
 				"\tAlex Kloss",
 				"\tAnders Petersson",
 				"\tAndrew Fister",
-				"\tBenjamin Podszun",
 				"\tBrian Mattern",
 				"\tBrion Vibber",
 				"\tBuchner Johannes",
@@ -343,7 +348,6 @@ namespace Tomboy
 				"\tFrederic Crozat",
 				"\tGabriel Burt",
 				"\tGabriel de Perthuis",
-				"\tGreg Poirier",
 				"\tJakub Steiner",
 				"\tJames Westby",
 				"\tJamin Philip Gray",
