@@ -2,6 +2,7 @@
 using System;
 using System.Collections;
 using System.Collections.Generic;
+using System.Diagnostics;
 using System.Runtime.InteropServices;
 using System.Text;
 using System.Threading;
@@ -86,8 +87,52 @@ namespace Tomboy
 			// Highlight the parent
 			if (menu.AttachWidget != null)
 				menu.AttachWidget.State = Gtk.StateType.Selected;
+
+#if WIN32
+			BringToForeground ();
+#endif
 		}
 
+		public static void BringToForeground () {
+			try {
+				Process current_proc = Process.GetCurrentProcess ();
+				int current_proc_id = current_proc.Id;
+				bool set_foreground_window = true;
+				IntPtr window_handle = GetForegroundWindow ();
+
+				if (window_handle != IntPtr.Zero) {
+					set_foreground_window = false;
+
+					int window_handle_proc_id;
+					GetWindowThreadProcessId (window_handle, out window_handle_proc_id);
+
+					if (window_handle_proc_id != current_proc_id) {
+						set_foreground_window = true;
+					}
+				}
+
+				if (set_foreground_window) {
+					window_handle = current_proc.MainWindowHandle;
+
+					if (window_handle != IntPtr.Zero) {
+						SetForegroundWindow (window_handle);
+					}
+				}
+			} catch (Exception e) {
+				Logger.Error("Error pulling Tomboy to foreground: {0}", e);
+			}
+		}
+
+		[DllImport ("user32.dll", SetLastError = true)]
+		static extern uint GetWindowThreadProcessId (IntPtr hWnd, out int lpdwProcessId);
+
+		[DllImport ("user32.dll")]
+		static extern IntPtr GetForegroundWindow ();
+
+		[DllImport ("user32.dll")]
+		[return: MarshalAs (UnmanagedType.Bool)]
+		static extern bool SetForegroundWindow (IntPtr hWnd);
+
 		public static Gdk.Pixbuf GetIcon (string resource_name, int size)
 		{
 			return GetIcon (null, resource_name, size);
@@ -105,7 +150,7 @@ namespace Tomboy
 				return ret.ScaleSimple (size, size, Gdk.InterpType.Bilinear);
 			} catch (ArgumentException) {}
 
-			Logger.Log ("Unable to load icon '{0}'.", resource_name);
+			Logger.Debug ("Unable to load icon '{0}'.", resource_name);
 			return null;
 		}
 
@@ -132,12 +177,13 @@ namespace Tomboy
 			return MakeImageButton (image, label);
 		}
 
-		public static void ShowHelp (string help_uri,
+		public static void ShowHelp (string project,
+		                             string page,
 		                             Gdk.Screen screen,
 		                             Gtk.Window parent)
 		{
 			try {
-				Services.NativeApplication.DisplayHelp (help_uri, screen);
+				Services.NativeApplication.DisplayHelp (project, page, screen);
 			} catch {
 				string message =
 					Catalog.GetString ("The \"Tomboy Notes Manual\" could " +
@@ -514,7 +560,7 @@ namespace Tomboy
 				if (s.StartsWith ("file:////"))
 					s = s.Replace ("file:////", "file:///");
 
-				Logger.Log ("uri = {0}", s);
+				Logger.Debug ("uri = {0}", s);
 				try {
 					Uri uri = new Uri (s);
 					if (uri != null)
